@@ -70,7 +70,7 @@ pub fn generate_eth_account(
     account: u32,
     index: u32,
     passphrase: Option<&str>,
-) -> Result<libsecp256k1::SecretKey> {
+) -> Result<secp256k1::SecretKey> {
     let seed = Mnemonic::from_phrase_in(language, phrase)?.to_seed(passphrase.unwrap_or(""));
     let derive_path = format!("{}/{}'/0/{}", ETH_CHAIN, account, index);
     let account = Secp256k1ExtendedPrivKey::derive(&seed, derive_path.as_ref())?;
@@ -85,7 +85,7 @@ pub fn generate_btc_account(
     account: u32,
     index: u32,
     passphrase: Option<&str>,
-) -> Result<libsecp256k1::SecretKey> {
+) -> Result<secp256k1::SecretKey> {
     let seed = Mnemonic::from_phrase_in(language, phrase)?.to_seed(passphrase.unwrap_or(""));
     let derive_path = format!("{}/{}'/0/{}", BTC_CHAIN, account, index);
     let account = Secp256k1ExtendedPrivKey::derive(&seed, derive_path.as_ref())?;
